@@ -5,7 +5,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2016	PgPool Global Development Group
+ * Copyright (c) 2003-2017	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -847,8 +847,7 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 
 	if (pool_config->authentication_timeout > 0)
 	{
-		pool_signal(SIGALRM, authentication_timeout);
-		alarm(pool_config->authentication_timeout);
+		pool_alarm(authentication_timeout, pool_config->authentication_timeout);
 	}
 
 	/* read startup packet length */
@@ -856,8 +855,7 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 	{
 		pool_error("read_startup_packet: incorrect packet length (%d)", len);
 		pool_free_startup_packet(sp);
-		alarm(0);
-		pool_signal(SIGALRM, SIG_IGN);
+		pool_undo_alarm();
 		return NULL;
 	}
 	len = ntohl(len);
@@ -867,8 +865,7 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 	{
 		pool_error("read_startup_packet: incorrect packet length (%d)", len);
 		pool_free_startup_packet(sp);
-		alarm(0);
-		pool_signal(SIGALRM, SIG_IGN);
+		pool_undo_alarm();
 		return NULL;
 	}
 
@@ -877,8 +874,7 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 	{
 		pool_error("read_startup_packet: out of memory");
 		pool_free_startup_packet(sp);
-		alarm(0);
-		pool_signal(SIGALRM, SIG_IGN);
+		pool_undo_alarm();
 		return NULL;
 	}
 
@@ -886,8 +882,7 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 	if (pool_read(cp, sp->startup_packet, len))
 	{
 		pool_free_startup_packet(sp);
-		alarm(0);
-		pool_signal(SIGALRM, SIG_IGN);
+		pool_undo_alarm();
 		return NULL;
 	}
 
@@ -907,8 +902,7 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 			{
 				pool_error("read_startup_packet: out of memory");
 				pool_free_startup_packet(sp);
-				alarm(0);
-				pool_signal(SIGALRM, SIG_IGN);
+				pool_undo_alarm();
 				return NULL;
 			}
 			strncpy(sp->database, sp2->database, SM_DATABASE);
@@ -918,8 +912,7 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 			{
 				pool_error("read_startup_packet: out of memory");
 				pool_free_startup_packet(sp);
-				alarm(0);
-				pool_signal(SIGALRM, SIG_IGN);
+				pool_undo_alarm();
 				return NULL;
 			}
 			strncpy(sp->user, sp2->user, SM_USER);
@@ -939,8 +932,7 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 					{
 						pool_error("read_startup_packet: out of memory");
 						pool_free_startup_packet(sp);
-						alarm(0);
-						pool_signal(SIGALRM, SIG_IGN);
+						pool_undo_alarm();
 						return NULL;
 					}
 				}
@@ -952,8 +944,7 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 					{
 						pool_error("read_startup_packet: out of memory");
 						pool_free_startup_packet(sp);
-						alarm(0);
-						pool_signal(SIGALRM, SIG_IGN);
+						pool_undo_alarm();
 						return NULL;
 					}
 				}
@@ -986,8 +977,7 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 			{
 				pool_error("read_startup_packet: out of memory");
 				pool_free_startup_packet(sp);
-				alarm(0);
-				pool_signal(SIGALRM, SIG_IGN);
+				pool_undo_alarm();
 				return NULL;
 			}
 			sp->user = calloc(1, 1);
@@ -995,8 +985,7 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 			{
 				pool_error("read_startup_packet: out of memory");
 				pool_free_startup_packet(sp);
-				alarm(0);
-				pool_signal(SIGALRM, SIG_IGN);
+				pool_undo_alarm();
 				return NULL;
 			}
 			break;
@@ -1004,8 +993,7 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 		default:
 			pool_error("read_startup_packet: invalid major no: %d", sp->major);
 			pool_free_startup_packet(sp);
-			alarm(0);
-			pool_signal(SIGALRM, SIG_IGN);
+			pool_undo_alarm();
 			return NULL;
 	}
 
@@ -1020,8 +1008,7 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 								__FILE__, __LINE__);
 		pool_error("read_startup_packet: no PostgreSQL user name specified in startup packet");
 		pool_free_startup_packet(sp);
-		alarm(0);
-		pool_signal(SIGALRM, SIG_IGN);
+		pool_undo_alarm();
 		return NULL;
 	}
 
@@ -1033,8 +1020,7 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 
 	pool_debug("Protocol Major: %d Minor: %d database: %s user: %s",
 			   sp->major, sp->minor, sp->database, sp->user);
-	alarm(0);
-	pool_signal(SIGALRM, SIG_IGN);
+	pool_undo_alarm();
 	return sp;
 }
 
@@ -1299,15 +1285,19 @@ static RETSIGTYPE die(int sig)
 			/* Refuse further requests by closing listen socket */
 			if (child_inet_fd)
 			{
+#ifdef NOT_USED
 				pool_log("die: close listen socket");
+#endif
 				close(child_inet_fd);
 			}
 			close(child_unix_fd);
 
+#ifdef NOT_USED
 			if (idle == 0)
 			{
 				pool_debug("child receives smart shutdown request but it's not in idle state");
 			}
+#endif
 			break;
 
 		case SIGINT:	/* fast shutdown */
@@ -1315,7 +1305,9 @@ static RETSIGTYPE die(int sig)
 			child_exit(0);
 			break;
 		default:
+#ifdef NOT_USED
 			pool_error("die() received unknown signal: %d", sig);
+#endif
 			break;
 	}
 }
@@ -1330,7 +1322,9 @@ static RETSIGTYPE close_idle_connection(int sig)
 	POOL_CONNECTION_POOL *p = pool_connection_pool;
 	ConnectionInfo *info;
 
+#ifdef NOT_USED
 	pool_debug("child receives close connection request");
+#endif
 
 	for (j=0;j<pool_config->max_pool;j++, p++)
 	{
@@ -1455,7 +1449,9 @@ void child_exit(int code)
 {
 	if (getpid() == mypid)
 	{
+#ifdef NOT_USED
 		pool_log("child_exit: called from pgpool main. ignored.");
+#endif
 		return;
 	}
 
